dealloc

Function dealloc 

pub unsafe fn dealloc(ptr: *mut u8, layout: Layout)
Fallible deallocation matching standard alloc interface.

Safety

  • ptr is a block of memory currently allocated via this allocator and,
  • layout is the same layout that was used to allocate that block of memory.