pub struct NoOpAllocator;Expand description
An allocator that does not perform any actual allocation or deallocation.
This is useful when constructing Box and other dynamically allocated collections from raw pointers to pre-existing memory that is owned and managed elsewhere (e.g., by C++ code), to ensure that dropping the collection does not deallocate the underlying memory.