pub unsafe fn dealloc(ptr: *mut u8, layout: Layout)Expand description
Fallible deallocation matching standard alloc interface.
Safety
ptris a block of memory currently allocated via this allocator and,layoutis the same layout that was used to allocate that block of memory.