pub unsafe fn realloc(
ptr: *mut u8,
layout: Layout,
new_size: usize,
) -> Option<NonNull<u8>>Expand description
Fallible reallocation matching standard alloc interface.
Safety
ptris allocated via this allocator,layoutis the same layout that was used to allocate that block of memory,new_sizeis greater than zero,new_size, when rounded up to the nearest multiple oflayout.align(), does not overflow isize.